@@ -3,7 +3,7 @@ import warnings
 from flask import request, current_app as app
 from flask_restplus import Resource
 
-from prom2teams.app.sender import AlarmSender
+from prom2teams.app.sender import AlertSender
 from prom2teams.prometheus.message_schema import MessageSchema
 from .model import *
 
@@ -17,7 +17,7 @@ class AlertReceiver(Resource):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.schema = MessageSchema()
-        self.sender = AlarmSender(template_path=app.config.get('TEMPLATE_PATH'),
+        self.sender = AlertSender(template_path=app.config.get('TEMPLATE_PATH'),
                                   teams_client_config=app.config.get('TEAMS_CLIENT_CONFIG'))
 
     @api_v1.expect(message)
@@ -25,7 +25,7 @@ class AlertReceiver(Resource):
         _show_deprecated_warning("Call to deprecated function. It will be removed in future versions. "
                                  "Please view the README file.")
         alerts = self.schema.load(request.get_json())
-        self.sender.send_alarms(alerts, app.config['MICROSOFT_TEAMS']['Connector'])
+        self.sender.send_alerts(alerts, app.config['MICROSOFT_TEAMS']['Connector'])
         return 'OK', 201
 
 
